@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2008  NTT DATA CORPORATION
  *
- * Version: 1.6.0   2008/04/01
+ * Version: 1.6.3   2008/07/15
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -114,11 +114,13 @@ int ccs_may_umount(struct vfsmount *mnt)
 		       ccs_get_msg(is_enforce), dir0, current->pid,
 		       exename);
 		if (is_enforce)
-			error = ccs_check_supervisor("# %s is requesting\n"
+			error = ccs_check_supervisor(NULL,
+						     "# %s is requesting\n"
 						     "unmount %s\n",
 						     exename, dir0);
 		ccs_free(exename);
-	}
+	} else
+		error = 0;
 	ccs_free(dir0);
  out:
 	if (!is_enforce)
